@@ -37,7 +37,7 @@
 #*/###########################################################################
 setConstructorS3("InternalErrorException", function(..., package=NULL) {
   if (!is.null(package) && !inherits(package, "Package")) {
-    package <- Package(as.character(package));
+    package <- Package(as.character(package))
   }
 
   extend(Exception(...), "InternalErrorException",
@@ -76,7 +76,7 @@ setConstructorS3("InternalErrorException", function(..., package=NULL) {
 # \keyword{error}
 #*/###########################################################################
 setMethodS3("getPackage", "InternalErrorException", function(this, ...) {
-  this$.package;
+  this$.package
 })
 
 
@@ -117,34 +117,15 @@ setMethodS3("getPackage", "InternalErrorException", function(this, ...) {
 # \keyword{error}
 #*/###########################################################################
 setMethodS3("getMessage", "InternalErrorException", function(this, ...) {
-  msg <- getMessage.Exception(this);
-  msg <- paste(msg, " This error is likely to be due to an internal error", sep="");
+  msg <- getMessage.Exception(this)
+  msg <- paste(msg, " This error is likely to be due to an internal error", sep="")
 
-  pkg <- getPackage(this);
+  pkg <- getPackage(this)
   if (!is.null(pkg)) {
-    msg <- paste(msg, " related to package ", getName(pkg), " v", getVersion(pkg), ". Please report this problem to the maintainer ", getMaintainer(pkg), " or the author ", getAuthor(pkg), " of that package", sep="");
+    msg <- paste(msg, " related to package ", getName(pkg), " v", getVersion(pkg), ". Please report this problem to the maintainer ", getMaintainer(pkg), " or the author ", getAuthor(pkg), " of that package", sep="")
   }
 
-  R.oo <- Package("R.oo");
-  msg <- paste(msg, ". Do not forget to report that you are using R v", getVersion(Package("base")), " on a ", R.Version()$platform, " platform together with R.oo v", getVersion(R.oo), ".", sep="");
-  msg;
+  R.oo <- Package("R.oo")
+  msg <- paste(msg, ". Do not forget to report that you are using R v", getVersion(Package("base")), " on a ", R.Version()$platform, " platform together with R.oo v", getVersion(R.oo), ".", sep="")
+  msg
 })
-
-
-############################################################################
-# HISTORY:
-# 2012-11-13
-# o ROBUSTNESS: Now getMessage() for InternalErrorException setups an
-#   Package("R.oo") object, instead of assuming that R.oo is loaded.
-# 2007-04-07
-# o Removed reportBug() for InternalErrorException.  Never completed/used.
-# 2005-02-15
-# o Added arguments '...' in order to match any generic functions.
-# 2003-12-02
-# o Bug report now generates a form process by the braju.com server.
-# 2003-04-15
-# o First trial version of a bug report system from within R that 
-#   automatically fills in the version information since that is the most
-#   commonly forgotten information.
-# o Created.
-############################################################################
